@@ -13,20 +13,20 @@ import optimism as opt
 
 # indentMessage tests
 m = opt.testFunction(functions.indentMessage)
-m.case('hi', 4).checkResult('  hi')
-m.case('hello', 4).checkResult('hello')
+m.case('hi', 4).checkReturnValue('  hi')
+m.case('hello', 4).checkReturnValue('hello')
 
 
 # printMessage tests
 m = opt.testFunction(functions.printMessage)
-m.case('hi', 4).checkOutputLines('  hi')
-m.case('hello', 4).checkOutputLines('hello')
+m.case('hi', 4).checkPrintedLines('  hi')
+m.case('hello', 4).checkPrintedLines('hello')
 
 
 # ellipseArea tests
 m = opt.testFunction(functions.ellipseArea)
-m.case(1, 1).checkResult(math.pi)
-m.case(2, 3).checkResult(6 * math.pi)
+m.case(1, 1).checkReturnValue(math.pi)
+m.case(2, 3).checkReturnValue(6 * math.pi)
 
 
 # No way to define test cases for polygon...
